@@ -75,6 +75,8 @@ task_postrun.connect(
 
 
 class CeleryApp(Celery):
+    registry_cls = 'tenant_schemas_celery.registry:TenantTaskRegistry'
+    
     def create_task_cls(self):
         return self.subclass_with_self(
             "tenant_schemas_celery.task:TenantTask",
@@ -82,3 +84,20 @@ class CeleryApp(Celery):
             name="TenantTask",
             attribute="_app",
         )
+
+    def _update_headers(self, kw):
+        kw["headers"] = kw.get("headers") or {}
+        self._add_current_schema(kw["headers"])
+
+    def _add_current_schema(self, kwds):
+        kwds["_schema_name"] = kwds.get("_schema_name", connection.schema_name)
+
+    def send_task(self, name, args=None, kwargs=None, **options):
+        if celery.VERSION[0] < 4:
+            kwargs = kwargs or {}
+            self._add_current_schema(kwargs)
+
+        else:
+            # Celery 4.0 introduced strong typing and the `headers` meta dict.
+            self._update_headers(options)
+        return super(CeleryApp, self).send_task(name, args=args, kwargs=kwargs, **options)
